@@ -17,10 +17,10 @@ from magicgui.types import FileDialogMode
 import numpy as np
 import napari
 
-from apoc import PredefinedFeatureSet, ObjectSegmenter, PixelClassifier
+from apoc import PredefinedFeatureSet, ObjectSegmenter, PixelClassifier, ProbabilityMapper
 from napari_tools_menu import register_dock_widget
 
-@register_dock_widget(menu="Segmentation > Object segmentation (APOC)")
+@register_dock_widget(menu="Segmentation / labeling > Object segmentation (APOC)")
 class ObjectSegmentation(QWidget):
     def __init__(self, napari_viewer, classifier_class=ObjectSegmenter):
         super().__init__()
@@ -61,7 +61,13 @@ class ObjectSegmentation(QWidget):
         training_widget.setLayout(QVBoxLayout())
 
         # Annotation
-        training_widget.layout().addWidget(QLabel("Select ground truth annotation / object label"))
+        if self.classifier_class == ObjectSegmentation:
+            suffix = " + object class"
+        elif self.classifier_class == ProbabilityMapper:
+            suffix = " + class for probability output"
+        else:
+            suffix = ""
+        training_widget.layout().addWidget(QLabel("Select ground truth annotation" + suffix))
         self.label_list = QComboBox()
         self.update_label_list()
 
@@ -74,9 +80,11 @@ class ObjectSegmentation(QWidget):
         num_object_annotation_spinner.setMaximumWidth(40)
         num_object_annotation_spinner.setMinimum(1)
         num_object_annotation_spinner.setValue(2)
-        if self.classifier_class != PixelClassifier:
-            print("classifier ", self.classifier_class)
+        if self.classifier_class == ObjectSegmentation:
             temp.layout().addWidget(num_object_annotation_spinner)
+        elif self.classifier_class == ProbabilityMapper:
+            temp.layout().addWidget(num_object_annotation_spinner)
+
         training_widget.layout().addWidget(temp)
 
         # Features
@@ -112,6 +120,10 @@ class ObjectSegmentation(QWidget):
                 warnings.warn("No ground truth annotation selected!")
                 return
 
+            if not self.check_image_sizes():
+                warnings.warn("Selected images and annotation must have the same dimensionality and size!")
+                return
+
             self.train(
                 self.get_selected_images_data(),
                 self.get_selected_annotation_data(),
@@ -213,8 +225,10 @@ class ObjectSegmentation(QWidget):
             num_ensembles=num_trees,
             max_depth=num_max_depth)
 
-        if hasattr(clf, "positive_class_identifier"):
+        if self.classifier_class == ObjectSegmenter:
             clf.positive_class_identifier = object_annotation_value
+        elif self.classifier_class == ProbabilityMapper:
+            clf.output_probability_of_class = object_annotation_value
 
         print("annotation shape", annotation.shape)
 
@@ -234,7 +248,10 @@ class ObjectSegmentation(QWidget):
             self.viewer.layers[name].data = data
             self.viewer.layers[name].visible = True
         except KeyError:
-            self.viewer.add_labels(data, name=name)
+            if self.classifier_class == ProbabilityMapper:
+                self.viewer.add_image(data, name=name)
+            else:
+                self.viewer.add_labels(data, name=name)
 
     def predict(self, images, filename):
         print("predict")
@@ -288,6 +305,13 @@ class ObjectSegmentation(QWidget):
                 i = i + 1
         self.label_list.setCurrentIndex(selected_index)
 
+    def check_image_sizes(self):
+        labels = self.get_selected_annotation_data()
+        for image in self.get_selected_images_data():
+            if not np.array_equal(image.shape, labels.shape):
+                return False
+        return True
+
     def get_selected_annotation(self):
         index = self.label_list.currentIndex()
         if index >= 0:
@@ -359,11 +383,17 @@ class ObjectSegmentation(QWidget):
         if num_images_in_viewer != self.image_list.size():
             self.update_image_list()
 
-@register_dock_widget(menu="Segmentation > Semantic segmentation (APOC)")
+@register_dock_widget(menu="Segmentation / labeling > Semantic segmentation (APOC)")
 class SemanticSegmentation(ObjectSegmentation):
     def __init__(self, napari_viewer):
         super().__init__(napari_viewer, classifier_class=PixelClassifier)
 
+@register_dock_widget(menu="Filtering > Probability mapper (APOC)")
+class ProbabilityMapping(ObjectSegmentation):
+    def __init__(self, napari_viewer):
+        super().__init__(napari_viewer, classifier_class=ProbabilityMapper)
+
+
 class FeatureSelector(QWidget):
     def __init__(self, feature_definition:str):
         super().__init__()
@@ -425,7 +455,7 @@ class FeatureSelector(QWidget):
     def getFeatures(self):
         return self.feature_definition.replace("  ", " ").strip(" ")
 
-@register_dock_widget(menu="Segmentation > Object classification (APOC)")
+@register_dock_widget(menu="Segmentation post-processing > Object classification (APOC)")
 class ObjectClassifier(QWidget):
     def __init__(self, napari_viewer):
         super().__init__()
