@@ -1,4 +1,4 @@
-from apoc import PredefinedFeatureSet, PixelClassifier, ObjectSegmenter, ObjectClassifier
+from apoc import PredefinedFeatureSet, PixelClassifier, ObjectSegmenter, ObjectClassifier, ProbabilityMapper
 
 import numpy as np
 from napari_plugin_engine import napari_hook_implementation
@@ -12,6 +12,7 @@ def napari_experimental_provide_function():
     return [
         Train_object_segmentation,
         Apply_object_segmentation,
+        Apply_probability_mapper,
         Train_object_segmentation_from_visible_image_layers,
         Apply_object_segmentation_to_visible_image_layers,
         Train_pixel_classifier,
@@ -39,7 +40,7 @@ def Train_pixel_classifier(
     result = clf.predict(features=feature_stack, image=image)
     return result
 
-@register_function(menu="Segmentation > Semantic segmentation (apply pretrained, APOC)")
+@register_function(menu="Segmentation / labeling > Semantic segmentation (apply pretrained, APOC)")
 @time_slicer
 def Apply_pixel_classification(image: "napari.types.ImageData",
                                model_filename : str = "PixelClassifier.cl",
@@ -101,7 +102,17 @@ def Train_object_segmentation(
     return result
 
 
-@register_function(menu="Segmentation > Object segmentation (apply pretrained, APOC)")
+@register_function(menu="Filtering > Probability Mapper (apply pretrained, APOC)")
+@time_slicer
+def Apply_probability_mapper(image: "napari.types.ImageData",
+                              model_filename : str = "ProbabilityMapper.cl",
+                              viewer: napari.Viewer = None) -> "napari.types.ImageData":
+    clf = ProbabilityMapper(opencl_filename=model_filename)
+    result = clf.predict(image=image)
+    return result
+
+
+@register_function(menu="Segmentation / labeling > Object segmentation (apply pretrained, APOC)")
 @time_slicer
 def Apply_object_segmentation(image: "napari.types.ImageData",
                               model_filename : str = "ObjectSegmenter.cl",
@@ -211,7 +222,7 @@ def Train_object_classifier(image: "napari.types.ImageData",
     result = clf.predict(labels, image)
     return result
 
-@register_function(menu="Segmentation > Object classification (apply pretrained, APOC)")
+@register_function(menu="Segmentation post-processing > Object classification (apply pretrained, APOC)")
 @time_slicer
 def Apply_object_classification(image: "napari.types.ImageData",
                              labels: "napari.types.LabelsData",
